EXPORTS
	?Text@CESMRAlarm@@QAEPAVHBufC16@@XZ @ 1 NONAME ; class HBufC16 * CESMRAlarm::Text(void)
	?GetMaskIconBitmap@NMRBitmapManager@@YAHW4TMRBitmapId@1@AAPAVCFbsBitmap@@1HVTSize@@@Z @ 2 NONAME ; int NMRBitmapManager::GetMaskIconBitmap(enum NMRBitmapManager::TMRBitmapId, class CFbsBitmap * &, class CFbsBitmap * &, int, class TSize)
	?GetFieldRowLayoutRect@NMRLayoutManager@@YA?AVTAknLayoutRect@@ABVTRect@@H@Z @ 3 NONAME ; class TAknLayoutRect NMRLayoutManager::GetFieldRowLayoutRect(class TRect const &, int)
	?GetLayoutText@NMRLayoutManager@@YA?AVTAknLayoutText@@ABVTRect@@W4TMRTextLayout@1@@Z @ 4 NONAME ; class TAknLayoutText NMRLayoutManager::GetLayoutText(class TRect const &, enum NMRLayoutManager::TMRTextLayout)
	??0TMenuItem@CMRStylusPopupMenu@@QAE@XZ @ 5 NONAME ; CMRStylusPopupMenu::TMenuItem::TMenuItem(void)
	?GetContactManager@CESMRContactManagerHandler@@QAEAAVCVPbkContactManager@@XZ @ 6 NONAME ; class CVPbkContactManager & CESMRContactManagerHandler::GetContactManager(void)
	?SetCommandObserver@CESMRContactMenuHandler@@QAEXPAVMEikCommandObserver@@@Z @ 7 NONAME ; void CESMRContactMenuHandler::SetCommandObserver(class MEikCommandObserver *)
	?AddObserverL@CESMRContactManagerHandler@@QAEXPAVMESMRContactManagerObserver@@@Z @ 8 NONAME ; void CESMRContactManagerHandler::AddObserverL(class MESMRContactManagerObserver *)
	?NewL@CMRButton@@SAPAV1@W4TMRBitmapId@NMRBitmapManager@@PBVCCoeControl@@W4TScaleMode@@@Z @ 9 NONAME ; class CMRButton * CMRButton::NewL(enum NMRBitmapManager::TMRBitmapId, class CCoeControl const *, enum TScaleMode)
	?SetColor@NMRColorManager@@YAXAAVCCoeControl@@W4TMRColorId@1@@Z @ 10 NONAME ; void NMRColorManager::SetColor(class CCoeControl &, enum NMRColorManager::TMRColorId)
	?Color@NMRColorManager@@YA?AVTRgb@@W4TMRColorId@1@@Z @ 11 NONAME ; class TRgb NMRColorManager::Color(enum NMRColorManager::TMRColorId)
	?OptionsMenuAvailable@CESMRContactMenuHandler@@QAEHXZ @ 12 NONAME ; int CESMRContactMenuHandler::OptionsMenuAvailable(void)
	?IsReady@CESMRContactManagerHandler@@QAEHXZ @ 13 NONAME ; int CESMRContactManagerHandler::IsReady(void)
	?SendAsVCalendarL@CESMRSendUI@@QAEXHAAVCCalEntry@@@Z @ 14 NONAME ; void CESMRSendUI::SendAsVCalendarL(int, class CCalEntry &)
	??0CESMRRecurrence@@QAE@XZ @ 15 NONAME ; CESMRRecurrence::CESMRRecurrence(void)
	?NewL@CMRLabel@@SAPAV1@PBVCCoeControl@@@Z @ 16 NONAME ; class CMRLabel * CMRLabel::NewL(class CCoeControl const *)
	?NewL@CMRImage@@SAPAV1@W4TMRBitmapId@NMRBitmapManager@@PBVCCoeControl@@HW4TScaleMode@@@Z @ 17 NONAME ; class CMRImage * CMRImage::NewL(enum NMRBitmapManager::TMRBitmapId, class CCoeControl const *, int, enum TScaleMode)
	?LoadTextL@CESMRAlarm@@QAEXPAVCCoeEnv@@@Z @ 18 NONAME ; void CESMRAlarm::LoadTextL(class CCoeEnv *)
	?GetSkinBasedBitmapLC@NMRBitmapManager@@YAXW4TMRBitmapId@1@AAPAVCFbsBitmap@@1VTSize@@@Z @ 19 NONAME ; void NMRBitmapManager::GetSkinBasedBitmapLC(enum NMRBitmapManager::TMRBitmapId, class CFbsBitmap * &, class CFbsBitmap * &, class TSize)
	??1RESMRStatic@@QAE@XZ @ 20 NONAME ; RESMRStatic::~RESMRStatic(void)
	??1CMRImage@@UAE@XZ @ 21 NONAME ; CMRImage::~CMRImage(void)
	?ExecuteL@CESMRGlobalNote@@SAXW4TESMGlobalNoteType@1@@Z @ 22 NONAME ; void CESMRGlobalNote::ExecuteL(enum CESMRGlobalNote::TESMGlobalNoteType)
	?ExecuteL@CESMRConfirmationQuery@@SAHW4TESMRConfirmationQueryType@1@@Z @ 23 NONAME ; int CESMRConfirmationQuery::ExecuteL(enum CESMRConfirmationQuery::TESMRConfirmationQueryType)
	?RecurrenceText@CESMRRecurrence@@QAEAAVHBufC16@@XZ @ 24 NONAME ; class HBufC16 & CESMRRecurrence::RecurrenceText(void)
	?NewL@CESMRGlobalNote@@SAPAV1@W4TESMGlobalNoteType@1@@Z @ 25 NONAME ; class CESMRGlobalNote * CESMRGlobalNote::NewL(enum CESMRGlobalNote::TESMGlobalNoteType)
	?ExecuteL@CESMRConfirmationQuery@@SAHABVTDesC16@@@Z @ 26 NONAME ; int CESMRConfirmationQuery::ExecuteL(class TDesC16 const &)
	?Id@CESMRAlarm@@QAEHXZ @ 27 NONAME ; int CESMRAlarm::Id(void)
	?ExecuteLD@CESMRGlobalNote@@QAEXXZ @ 28 NONAME ; void CESMRGlobalNote::ExecuteLD(void)
	?ExecuteLD@CESMRListQuery@@QAEHXZ @ 29 NONAME ; int CESMRListQuery::ExecuteLD(void)
	?GetFieldLayoutRect@NMRLayoutManager@@YA?AVTAknLayoutRect@@ABVTRect@@H@Z @ 30 NONAME ; class TAknLayoutRect NMRLayoutManager::GetFieldLayoutRect(class TRect const &, int)
	?SetValueL@CESMRContactMenuHandler@@QAEXABVTDesC16@@W4TValueType@1@@Z @ 31 NONAME ; void CESMRContactMenuHandler::SetValueL(class TDesC16 const &, enum CESMRContactMenuHandler::TValueType)
	?GetBitmapStruct@NMRBitmapManager@@YA?AVTMRBitmapStruct@1@W4TMRBitmapId@1@@Z @ 32 NONAME ; class NMRBitmapManager::TMRBitmapStruct NMRBitmapManager::GetBitmapStruct(enum NMRBitmapManager::TMRBitmapId)
	?ExecuteL@CESMRListQuery@@SAHW4TESMRListQueryType@1@@Z @ 33 NONAME ; int CESMRListQuery::ExecuteL(enum CESMRListQuery::TESMRListQueryType)
	?Close@RESMRStatic@@QAEXXZ @ 34 NONAME ; void RESMRStatic::Close(void)
	?LaunchPopupL@CMRStylusPopupMenu@@QAEXV?$TArray@VTMenuItem@CMRStylusPopupMenu@@@@ABVTPoint@@@Z @ 35 NONAME ; void CMRStylusPopupMenu::LaunchPopupL(class TArray<class CMRStylusPopupMenu::TMenuItem>, class TPoint const &)
	?NewL@CESMRListQuery@@SAPAV1@W4TESMRListQueryType@1@AAV?$RArray@H@@@Z @ 36 NONAME ; class CESMRListQuery * CESMRListQuery::NewL(enum CESMRListQuery::TESMRListQueryType, class RArray<int> &)
	?ShowActionMenuL@CESMRContactMenuHandler@@QAEXXZ @ 37 NONAME ; void CESMRContactMenuHandler::ShowActionMenuL(void)
	?ContactMenuHandlerL@RESMRStatic@@QAEAAVCESMRContactMenuHandler@@XZ @ 38 NONAME ; class CESMRContactMenuHandler & RESMRStatic::ContactMenuHandlerL(void)
	??0TMenuItem@CMRStylusPopupMenu@@QAE@ABVTDesC16@@H@Z @ 39 NONAME ; CMRStylusPopupMenu::TMenuItem::TMenuItem(class TDesC16 const &, int)
	??1CESMRRecurrence@@UAE@XZ @ 40 NONAME ; CESMRRecurrence::~CESMRRecurrence(void)
	??0RESMRStatic@@QAE@XZ @ 41 NONAME ; RESMRStatic::RESMRStatic(void)
	?DisplaySendCascadeMenuL@CESMRSendUI@@QAEXAAVCEikMenuPane@@@Z @ 42 NONAME ; void CESMRSendUI::DisplaySendCascadeMenuL(class CEikMenuPane &)
	?ExecuteLD@CESMRListQuery@@QAEHAAV?$RArray@VTPtrC16@@@@@Z @ 43 NONAME ; int CESMRListQuery::ExecuteLD(class RArray<class TPtrC16> &)
	?ExecuteOptionsMenuL@CESMRContactMenuHandler@@QAEXH@Z @ 44 NONAME ; void CESMRContactMenuHandler::ExecuteOptionsMenuL(int)
	?NewL@CESMRSendUI@@SAPAV1@H@Z @ 45 NONAME ; class CESMRSendUI * CESMRSendUI::NewL(int)
	??1CMRLabel@@UAE@XZ @ 46 NONAME ; CMRLabel::~CMRLabel(void)
	?CurrentFieldIndex@RESMRStatic@@QAEHXZ @ 47 NONAME ; int RESMRStatic::CurrentFieldIndex(void)
	?GetSkinBasedBitmap@NMRBitmapManager@@YAHW4TMRBitmapId@1@AAPAVCFbsBitmap@@1VTSize@@@Z @ 48 NONAME ; int NMRBitmapManager::GetSkinBasedBitmap(enum NMRBitmapManager::TMRBitmapId, class CFbsBitmap * &, class CFbsBitmap * &, class TSize)
	?RemoveObserver@CESMRContactManagerHandler@@QAEXPAVMESMRContactManagerObserver@@@Z @ 49 NONAME ; void CESMRContactManagerHandler::RemoveObserver(class MESMRContactManagerObserver *)
	?ConstructFromResourceL@CESMRAlarm@@QAEXAAVTResourceReader@@@Z @ 50 NONAME ; void CESMRAlarm::ConstructFromResourceL(class TResourceReader &)
	?RecurrenceValue@CESMRRecurrence@@QAE?AW4TESMRRecurrenceValue@@XZ @ 51 NONAME ; enum TESMRRecurrenceValue CESMRRecurrence::RecurrenceValue(void)
	?RelativeTimeInMinutes@CESMRAlarm@@QAE?AVTTimeIntervalMinutes@@XZ @ 52 NONAME ; class TTimeIntervalMinutes CESMRAlarm::RelativeTimeInMinutes(void)
	?CanSendL@CESMRSendUI@@QAEHH@Z @ 53 NONAME ; int CESMRSendUI::CanSendL(int)
	?DisplaySendMenuItemL@CESMRSendUI@@QAEXAAVCEikMenuPane@@H@Z @ 54 NONAME ; void CESMRSendUI::DisplaySendMenuItemL(class CEikMenuPane &, int)
	??1CMRButton@@UAE@XZ @ 55 NONAME ; CMRButton::~CMRButton(void)
	?SetColor@NMRColorManager@@YAXAAVCEikTTimeEditor@@W4TMRColorId@1@@Z @ 56 NONAME ; void NMRColorManager::SetColor(class CEikTTimeEditor &, enum NMRColorManager::TMRColorId)
	?ContactManagerHandlerL@RESMRStatic@@QAEAAVCESMRContactManagerHandler@@XZ @ 57 NONAME ; class CESMRContactManagerHandler & RESMRStatic::ContactManagerHandlerL(void)
	?ExecuteEditBeforeSendL@CESMRListQuery@@SAHW4TESMRAttendeeStatus@@@Z @ 58 NONAME ; int CESMRListQuery::ExecuteEditBeforeSendL(enum TESMRAttendeeStatus)
	?GetLayoutRect@NMRLayoutManager@@YA?AVTAknLayoutRect@@ABVTRect@@W4TMRLayout@1@@Z @ 59 NONAME ; class TAknLayoutRect NMRLayoutManager::GetLayoutRect(class TRect const &, enum NMRLayoutManager::TMRLayout)
	?Reset@CESMRContactMenuHandler@@QAEXXZ @ 60 NONAME ; void CESMRContactMenuHandler::Reset(void)
	?SetContactMenuObserver@CESMRContactMenuHandler@@QAEXPAVMMRContactMenuObserver@@@Z @ 61 NONAME ; void CESMRContactMenuHandler::SetContactMenuObserver(class MMRContactMenuObserver *)
	?ExecuteL@CESMRGUIListQuery@@SAHW4TESMRListQueryType@1@@Z @ 62 NONAME ; int CESMRGUIListQuery::ExecuteL(enum CESMRGUIListQuery::TESMRListQueryType)
	?ConnectL@RESMRStatic@@QAEXXZ @ 63 NONAME ; void RESMRStatic::ConnectL(void)
	?ExecuteEditBeforeSendWithSendOptOnlyL@CESMRListQuery@@SAHW4TESMRAttendeeStatus@@@Z @ 64 NONAME ; int CESMRListQuery::ExecuteEditBeforeSendWithSendOptOnlyL(enum TESMRAttendeeStatus)
	?ExecuteL@CESMRListQuery@@SAHW4TESMRListQueryType@1@AAV?$RArray@H@@@Z @ 65 NONAME ; int CESMRListQuery::ExecuteL(enum CESMRListQuery::TESMRListQueryType, class RArray<int> &)
	?NewL@CESMRListQuery@@SAPAV1@W4TESMRListQueryType@1@@Z @ 66 NONAME ; class CESMRListQuery * CESMRListQuery::NewL(enum CESMRListQuery::TESMRListQueryType)
	?GetTextComponentLayout@NMRLayoutManager@@YA?AVTAknTextComponentLayout@@W4TMRTextLayout@1@@Z @ 67 NONAME ; class TAknTextComponentLayout NMRLayoutManager::GetTextComponentLayout(enum NMRLayoutManager::TMRTextLayout)
	?ConstructFromResourceL@CESMRRecurrence@@QAEXPAVCCoeEnv@@AAVTResourceReader@@@Z @ 68 NONAME ; void CESMRRecurrence::ConstructFromResourceL(class CCoeEnv *, class TResourceReader &)
	?GetWindowComponentLayout@NMRLayoutManager@@YA?AVTAknWindowComponentLayout@@W4TMRLayout@1@@Z @ 69 NONAME ; class TAknWindowComponentLayout NMRLayoutManager::GetWindowComponentLayout(enum NMRLayoutManager::TMRLayout)
	?InitOptionsMenuL@CESMRContactMenuHandler@@QAEXPAVCEikMenuPane@@@Z @ 70 NONAME ; void CESMRContactMenuHandler::InitOptionsMenuL(class CEikMenuPane *)
	?Relative@CESMRAlarm@@QAEHXZ @ 71 NONAME ; int CESMRAlarm::Relative(void)
	?ExecuteL@CESMRListQuery@@SAHW4TESMRListQueryType@1@AAV?$RArray@VTPtrC16@@@@@Z @ 72 NONAME ; int CESMRListQuery::ExecuteL(enum CESMRListQuery::TESMRListQueryType, class RArray<class TPtrC16> &)
	??0CESMRAlarm@@QAE@XZ @ 73 NONAME ; CESMRAlarm::CESMRAlarm(void)
	?SetCurrentFieldIndex@RESMRStatic@@QAEXH@Z @ 74 NONAME ; void RESMRStatic::SetCurrentFieldIndex(int)
	?GetMaskIconBitmapLC@NMRBitmapManager@@YAXW4TMRBitmapId@1@AAPAVCFbsBitmap@@1HVTSize@@@Z @ 75 NONAME ; void NMRBitmapManager::GetMaskIconBitmapLC(enum NMRBitmapManager::TMRBitmapId, class CFbsBitmap * &, class CFbsBitmap * &, int, class TSize)
	??1CESMRSendUI@@UAE@XZ @ 76 NONAME ; CESMRSendUI::~CESMRSendUI(void)
	??1CMRStylusPopupMenu@@UAE@XZ @ 77 NONAME ; CMRStylusPopupMenu::~CMRStylusPopupMenu(void)
	?NewL@CMRStylusPopupMenu@@SAPAV1@AAVMEikMenuObserver@@@Z @ 78 NONAME ; class CMRStylusPopupMenu * CMRStylusPopupMenu::NewL(class MEikMenuObserver &)
	??1CESMRAlarm@@UAE@XZ @ 79 NONAME ; CESMRAlarm::~CESMRAlarm(void)
	?GetColorStruct@NMRColorManager@@YA?AVTMRColorStruct@1@W4TMRColorId@1@@Z @ 80 NONAME ; class NMRColorManager::TMRColorStruct NMRColorManager::GetColorStruct(enum NMRColorManager::TMRColorId)

